<template>
  <AppHead :title="data.title"> </AppHead>

  <div class="container page-container">
    <div class="row">
      <div class="col-md-12">
        <h2 class="card-title">{{ data.title }}</h2>
        <hr />
      </div>

      <div v-if="!exam_started">
        <p v-html="data.instruction"></p>
        <button
          :disabled="loading"
          @click="getMcq()"
          type="submit"
          class="btn btn-primary"
        >
        <i class="fa-regular fa-clock"></i> {{ __("Start Exam") }}
        </button>
      </div>

      <div class="loader mx-auto" v-if="loading"></div>

      <!-- Start -->
      <div v-if="exam_started">
        <p class="text-danger">{{ __("Time remaining") }} : {{ formattedTime }}</p>
        <div v-if="timeRemaining > 0">
          <div v-if="currentQuestion" class="border p-4">
            <div>
              {{ __("Question") }} : {{ currentQuestion.number }} /
              {{ total_mcq_questions }}
            </div>
            <h2 class="h4 mt-2 mb-4">{{ currentQuestion.question_text }}</h2>
            <div>              
              <Radio v-model="selectedOption" :options="[
              { 'id' : 'a', 'name' : currentQuestion.option_a},
              { 'id' : 'b', 'name' : currentQuestion.option_b},
              { 'id' : 'c', 'name' : currentQuestion.option_c},
              { 'id' : 'd', 'name' : currentQuestion.option_d},
              ]"/>           
            </div>
          
            <button class="btn btn-primary mt-4" @click="submitAnswer">{{ __('Next') }} <i class="fa-solid fa-arrow-right-long"></i></button>
          </div>
          <div v-else>
            <p>{{ __('All questions answered. Thank you!') }}</p>
          </div>
        </div>
        <div v-else>
          <p>{{ __('Time is up! You can no longer submit answers.') }}</p>
        </div>
      </div>
      <!-- End -->
    </div>
  </div>
</template>

<script>
import { Input, Radio, SubmitButton } from "../../../components/Form/Index.js";

export default {
  props: ["data"],
  components: {
    Input,
    Radio,
    SubmitButton,
  },
  computed: {
    currentQuestion() {
      return this.questions ? this.questions[this.currentIndex] : null;
    },
    formattedTime() {
      const minutes = Math.floor(this.timeRemaining / 60);
      const seconds = this.timeRemaining % 60;
      return `${minutes}:${seconds < 10 ? "0" : ""}${seconds}`;
    },
  },
  beforeDestroy() {
    clearInterval(this.timer);
  },
  data() {
    return {
      total_mcq_questions: 0,
      exam_started: null,
      questions: null,
      loading: null,
      currentIndex: 0,
      selectedOption: "",
      timeRemaining: 0, // in seconds
      timer: null,
    };
  },
  methods: {
    startTimer(remainingTime) {
      //this.timeRemaining = remainingTime * 60; // 20 minutes in seconds
      this.timeRemaining = parseInt(remainingTime);

      this.timer = setInterval(() => {
        if (this.timeRemaining > 0) {
          this.timeRemaining--;
        } else {
          clearInterval(this.timer);
        }
      }, 1000);
    },
    getMcq() {
      this.loading = true;
      let scope = this;
      axios
        .get(
          route(
            "public.author.assessment.getMultipleChoiceQuestions",
            this.data.applicant_uuid
          )
        )
        .then(function (response) {
          scope.exam_started = true;
          scope.loading = false;
          scope.total_mcq_questions = response.data.total_mcq_questions;
          scope.questions = response.data.questions;
          scope.startTimer(response.data.time_remaining);
        });
    },
    submitAnswer() {
      if (this.selectedOption) {
        const payload = {
          assessment_question_id: this.currentQuestion.id,
          entered_option: this.selectedOption,
        };

        axios
          .post(
            route(
              "public.author.assessment.postMultipleChoiceAnswer",
              this.data.applicant_uuid
            ),
            payload
          )
          .then((response) => {
            console.log("Answer submitted:", response.data);
            this.currentIndex++;
            this.selectedOption = "";
            if (response.data.redirect_link) {
              this.$inertia.visit(response.data.redirect_link);
            }
          })
          .catch((error) => {
            console.error("Error submitting answer:", error);
          });
      } else {
        alert("Please select an option before proceeding.");
      }
    },
  },
};
</script>

<style>
.loader {
  border: 16px solid #f3f3f3; /* Light grey */
  border-top: 16px solid #3498db; /* Blue */
  border-radius: 50%;
  width: 120px;
  height: 120px;
  animation: spin 2s linear infinite;
}

@keyframes spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}
</style>
